#
# spec file for package pwdutils (Version 3.0.7.1)
#
# Copyright (c) 2010 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# norootforbuild


Name:           pwdutils
BuildRequires:  audit-devel libnscd-devel libxcrypt-devel openldap2-devel openslp-devel openssl-devel pam-devel
Url:            http://www.thkukuk.de/pam/pwdutils/
License:        BSD 3-Clause; GPL v2 or later
Group:          System/Base
AutoReqProv:    on
Version:        3.0.7.1
Release:        17.34.41
Summary:        Utilities to Manage User and Group Accounts
PreReq:         grep /bin/cp /bin/mv
Requires:       pam-modules
Provides:       shadow shadow-utils
Obsoletes:      cpu shadow shadow-utils
Source:         pwdutils-%{version}.tar.bz2
Source1:        pam_login-3.31.tar.bz2
Source2:        ldap.conf
Source3:        useradd.default
Source4:        passwd.default
Source11:       chage.pamd
Source12:       chfn.pamd
Source13:       chsh.pamd
Source14:       login.pamd
Source15:       passwd.pamd
Source16:       rpasswd.pamd
Source17:       shadow.pamd
Source18:       useradd.pamd
Patch:          pwdutils-3.0.5.dif
Patch1:         pwdutils-libldap.diff
Patch2:         bugzilla-148065.patch
Patch3:         pwdutils-ldap-rfc2307bis.diff
Patch4:         pam_login-3.31.diff
Patch5:         pam_login-3.31-suppress_hostname.patch
Patch6:         pwdutils-usermod-bnc177144.diff
Patch7:         pwdutils-newgrp-bnc173696.diff
Patch8:         pwdutils-gpasswd-bnc190931.diff
Patch9:         pam_login-audit.diff
Patch10:        pwdutils-plugin-audit-newfunction.diff
Patch11:        libuser-fsync.diff
Patch12:        pam_login-bnc527336-hushlogin.diff
Patch13:        pwdutils-bnc527336-hushlogin.diff
Patch14:        pwdutils-userdel-bnc551823.diff
Patch15:        pwdutils-usermod-bnc645140.diff
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
This package includes the necessary programs for login onto a system on
the console, converting plain password files to the shadow password
format, and managing user and group accounts in both local files and in
a LDAP database.



%package plugin-audit
License:        BSD 3-Clause; GPL v2 or later
Summary:        Plugin for the Linux Audit-Subsystem
Group:          System/Base
Requires:       pwdutils = %{version}
AutoReqProv:    on

%description plugin-audit
This package includes the plugin for the password/account management
utilities to use the Linux Audit-Subsystem for logging.

To enable this plugin, please add "audit" to /etc/pwdutils/logging.



%prep
%setup -q -b 1
%patch
%patch1
pushd ../pam_login-*
%patch2 -p0
%patch4
%patch5 -p1
%patch9 -p1
%patch12
popd
%patch3
%patch6
%patch7
%patch8
%patch10
%patch11
%patch13
%patch14
chmod 755 src/tst-usermod
%patch15

%build
CFLAGS="$RPM_OPT_FLAGS -fno-strict-aliasing" \
 ./configure --with-ldap-conf-file=/etc/ldap.conf \
%ifnarch hppa
	--enable-selinux \
%else
	--disable-selinux \
%endif
	--enable-pam_rpasswd --enable-audit-plugin --libdir=%{_libdir}
make
#make check
cd ../pam_login-*
autoreconf -i -f
CFLAGS="$RPM_OPT_FLAGS" ./configure --with-audit=yes

%install
cd ../pam_login-*
make install DESTDIR=$RPM_BUILD_ROOT
cd ../pwdutils-*
make install DESTDIR=$RPM_BUILD_ROOT
rm -f $RPM_BUILD_ROOT%{_libdir}/pwdutils/lib*.so
mkdir $RPM_BUILD_ROOT/%{_lib}
mv $RPM_BUILD_ROOT%{_libdir}/security $RPM_BUILD_ROOT/%{_lib}
/sbin/ldconfig -n %{_libdir}/pwdutils
rm -f $RPM_BUILD_ROOT%{_libdir}/pwdutils/*a
ln -sf ../../etc/init.d/rpasswdd $RPM_BUILD_ROOT/usr/sbin/rcrpasswdd
ln -sf newgrp $RPM_BUILD_ROOT/usr/bin/sg
install -m 644 $RPM_SOURCE_DIR/ldap.conf $RPM_BUILD_ROOT/etc
install -m 644 $RPM_SOURCE_DIR/useradd.default $RPM_BUILD_ROOT/etc/default/useradd
install -m 644 $RPM_SOURCE_DIR/passwd.default $RPM_BUILD_ROOT/etc/default/passwd
echo ".so man8/useradd.8" > $RPM_BUILD_ROOT%{_mandir}/man8/adduser.8
cd ../pwdutils-*
#
# install our pam config files
#
for i in chage chfn chsh login passwd rpasswd shadow useradd ; do
 install -m 644 $RPM_SOURCE_DIR/$i.pamd $RPM_BUILD_ROOT/etc/pam.d/$i
done
#
# Find all translations
#
%{find_lang} pwdutils
%{find_lang} pam_login pwdutils.lang

%clean
rm -rf $RPM_BUILD_ROOT

%pre
if [ "0$1" -ge "2" ]; then
# If we have a /etc/openldap/ldap.conf, which is modified,
# and no /etc/ldap.conf, copy /etc/openldap.conf before we
# install our own version. But only on update.
   if [ ! -e /etc/ldap.conf -a -f /etc/openldap/ldap.conf ]; then
      grep -v '^#' /etc/openldap/ldap.conf > /dev/null
      if [ $? == 0 ]; then
         cp -p /etc/openldap/ldap.conf /etc/...ldap.conf.new
      fi
   fi
fi

%post
# If we backuped the openldap/ldap.conf, move now the backup
# in place
test -f /etc/...ldap.conf.new && mv /etc/...ldap.conf.new /etc/ldap.conf
# useradd.local was not owned by a package before, overwrite
# old file, if it is the dummy one.
if [ -f /usr/sbin/useradd.local.rpmnew ]; then
   grep -v '^#' /usr/sbin/useradd.local > /dev/null
   if [ $? == 0 ]; then
      mv /usr/sbin/useradd.local.rpmnew /usr/sbin/useradd.local
   fi
fi

%files -f pwdutils.lang
%defattr(-,root,root,755)
%doc AUTHORS COPYING NEWS README THANKS TODO
%attr(0644,root,root) %config(noreplace) /etc/ldap.conf
%config /etc/login.defs
%config(noreplace) /etc/rpasswd.conf
%config /etc/pam.d/chage
%config /etc/pam.d/chfn
%config /etc/pam.d/chsh
%config /etc/pam.d/login
%config /etc/pam.d/passwd
%config /etc/pam.d/rpasswd
%config /etc/pam.d/shadow
%config /etc/pam.d/useradd
%config /etc/init.d/rpasswdd
%config(noreplace) /etc/default/useradd
%config(noreplace) /etc/default/passwd
%dir /etc/pwdutils
%config(noreplace) /etc/pwdutils/logging
/%{_lib}/security/pam_rpasswd.so
/bin/login
%attr (4755,root,shadow) /usr/bin/chage
%attr (4755,root,shadow) /usr/bin/chfn
%attr (4755,root,shadow) /usr/bin/chsh
%attr (4755,root,shadow) /usr/bin/expiry
/usr/bin/faillog
%attr (4755,root,shadow) /usr/bin/gpasswd
/usr/bin/lastlog
%attr (4755,root,root) /usr/bin/newgrp
%attr (4755,root,shadow) /usr/bin/passwd
/usr/bin/rpasswd
/usr/bin/sg
%doc %{_mandir}/man?/*
/usr/sbin/chpasswd
/usr/sbin/groupadd
/usr/sbin/groupdel
/usr/sbin/groupmod
/usr/sbin/grpck
/usr/sbin/grpconv
/usr/sbin/grpunconv
/usr/sbin/pwck
/usr/sbin/pwconv
/usr/sbin/pwunconv
/usr/sbin/rcrpasswdd
/usr/sbin/rpasswdd
/usr/sbin/useradd
%verify(not md5 size mtime) %config(noreplace) /usr/sbin/groupadd.local
%verify(not md5 size mtime) %config(noreplace) /usr/sbin/useradd.local
%verify(not md5 size mtime) %config(noreplace) /usr/sbin/userdel-pre.local
%verify(not md5 size mtime) %config(noreplace) /usr/sbin/userdel-post.local
/usr/sbin/userdel
/usr/sbin/usermod
/usr/sbin/vigr
/usr/sbin/vipw
%dir %{_libdir}/pwdutils
%{_libdir}/pwdutils/liblog_syslog.so.1*

%files plugin-audit
%defattr(-,root,root,755)
%{_libdir}/pwdutils/liblog_audit.so.1*

%changelog
* Wed Oct 27 2010 kukuk@suse.de
- usermod: ignore non-regular files [bnc#645140]
* Wed Dec  2 2009 kukuk@suse.de
- Fix possible loop in userdel [bnc#551823]
* Tue Aug  4 2009 kukuk@suse.de
- Fix HUSHLOGIN_FILE handling and documentation [bnc#527336].
* Fri Jul 17 2009 kukuk@suse.de
- Make sure modified passwd/shadow file is written to disk
  [bnc#520125]
* Fri Apr 27 2007 draht@suse.de
- pwdutils-plugin-audit-newfunction.diff, fix for #266669, do use
  preferred and actually present function exported from libaudit.so
  instead of function that was removed from libaudit.
* Fri Mar  2 2007 tonyj@suse.de
- Fix for 244625.  Change pam_login to emit audit
  AUDIT_USER_LOGIN messages as expected by aureport.
* Mon Jan 29 2007 rhafer@suse.de
- Enabled pam_lookup_policy in default ldap.conf to make use of
  LDAP password policies, when they are available [#239798]
* Fri Jul 28 2006 kukuk@suse.de
- Let gpasswd abort if password was mistyped [#190932]
* Mon Jun 12 2006 kukuk@suse.de
- Abort if setuid() fails.
* Tue May 23 2006 kukuk@suse.de
- Save pointer for group entry [#173696]
* Mon May 22 2006 kukuk@suse.de
- Fix usermod -L/-U [#177144]
* Fri May 19 2006 kssingvo@suse.de
- added option -H to suppress hostname (bugzilla#175376)
* Thu May 18 2006 schwab@suse.de
- Don't strip binaries.
* Mon Mar 27 2006 kukuk@suse.de
- Add updated translations for /bin/login.
- Allow creating/updating LDAP groups according to RFC2307
  and RFC2307bis.
* Mon Mar  6 2006 kukuk@suse.de
- Add new translations for /bin/login.
* Tue Feb  7 2006 mfabian@suse.de
- bugzilla #148065: login.c:
  use locale environment variables if available and fall back to
  parsing /etc/sysconfig/language only if not.
  Observe LC_MESSAGE as well and don't use translations for
  languages which cannot be displayed currently on the Linux
  console.
* Mon Jan 30 2006 kukuk@suse.de
- Increase buffer in libldap of pwdutils
* Thu Jan 26 2006 kukuk@suse.de
- Remove unused -h option from passwd
- Add swedish translation
- Update german translation
* Fri Jan  6 2006 kukuk@suse.de
- Add bind_policy soft to ldap.conf [#139578]
* Thu Dec 22 2005 kukuk@suse.de
- Update to pam_login 3.29: Enable localisation of /bin/login
* Sat Dec 17 2005 kukuk@suse.de
- Workaround rpm 4.4.2
* Wed Dec 14 2005 kukuk@suse.de
- Move pam_mail into session section (to get correct order with
  lastlog message again)
* Mon Dec  5 2005 kukuk@suse.de
- Update to pwdutils 3.0.7 [#48508]
- Update to pam_login 3.27 (use pam_lastlog instead of doing it
  ourself)
- disable SELinux support
* Mon Oct 24 2005 kukuk@suse.de
- Fix sanity check for home phone in chfn [#130209]
* Thu Oct 13 2005 kukuk@suse.de
- Provide shadow-utils for 3rd party packages with broken
  (Pre)Requires [#128038]
* Mon Oct 10 2005 aj@suse.de
- Build with -fno-strict-aliasing.
* Tue Oct  4 2005 kukuk@suse.de
- pam_login: Update to 3.26 (build with new Linux-PAM headers)
- pwdutils: Update to 3.0.5 (build with new Linux-PAM headers)
* Sun Sep 25 2005 kukuk@suse.de
- Adjust for new OpenLDAP
* Sat Sep  3 2005 kukuk@suse.de
- Allow 'Z' in login names
* Fri Sep  2 2005 kukuk@suse.de
- Update to pam_login 3.25 (fixes crash with -h option, [#114694]
- pam_login: Disable debug mode
* Wed Aug 17 2005 kukuk@suse.de
- Update to pam_login 3.24 (update of manual pages)
- Update to pwdutils 3.0.4
  - usermod: Adjust sp_lstchg if -p option is used
  - useradd: Preserve existing home directory
  - chage: Fix off-by-one errors in output
  - Fix loading of logging plugins
  - Add -a option to usermod for shadow compatibility
* Wed Jun 22 2005 kukuk@suse.de
- Update to pwdutils 3.0.1
* Wed Jun 15 2005 kukuk@suse.de
- Use Linux Audit subsystem instead of LAuS
* Mon Jun 13 2005 kukuk@suse.de
- Update to pam_login 3.23 (add russian translation, remove old
  code)
* Fri Jun  3 2005 kukuk@suse.de
- Update to pwdutils 3.0:
  - Compile setuid binaries with -fpie/-pie
  - Add --stdin to passwd command
  - Create mail spool file if requested (useradd)
* Thu Apr 28 2005 kukuk@suse.de
- Update to pam_login 3.22 and pwdutils 2.6.98:
  - Remove SELinux support from /bin/login (should be done with PAM)
  - Check return values for errors
* Thu Apr  7 2005 kukuk@suse.de
- Remove faillog support from /bin/login
* Tue Apr  5 2005 kukuk@suse.de
- Update to 2.6.97: Compile daemons with -fpie/-fpie
* Mon Mar 28 2005 kukuk@suse.de
- Fix problems with gcc4
- Remove patch to remove shadow(5) references
* Mon Mar  7 2005 ke@suse.de
- In passwd(1) remove misleading shadow(5) reference; reported by
  Andreas Klein [# 66339].
* Tue Feb 22 2005 kukuk@suse.de
- Update to 2.6.96: Fix memory corruptions [#65909]
* Fri Dec 10 2004 kukuk@suse.de
- Update to 2.6.94: Create plugins for logging and create plugin
  for LAuS support
* Mon Nov 29 2004 kukuk@suse.de
- Update to 2.6.92 (includes fixes for [#48625,#48278,#47712])
* Mon Nov  8 2004 kukuk@suse.de
- Use common-auth for login.pamd, too
* Wed Oct 13 2004 kukuk@suse.de
- Update to 2.6.91 (merge all patches, include common-* pam config
  files)
* Fri Oct  1 2004 kukuk@suse.de
- Don't allow UINT_MAX (aka -1) as UID/GID [#46609]
  Workaround for broken kernel interface.
* Tue Sep 14 2004 kukuk@suse.de
- Use libnscd
* Mon Aug 23 2004 kukuk@suse.de
- Revert [#43329] (group dialout is misused in too many places)
* Mon Aug 23 2004 kukuk@suse.de
- Update to pam_login 3.20:
  - New nl translation
  - Special debug option
  - Fix for waitpid failures [#44012]
* Tue Aug 17 2004 kukuk@suse.de
- Update to pwdutils 2.6.90 (better SLP support, start to better
  integrate the LAuS patch).
- Remove "nullok" from all password entries in PAM config files,
  should be handled through the global pam_unix2 config file.
* Tue Jul 27 2004 kukuk@suse.de
- Don't add new users to the audio, dialout and uucp group [#43329]
* Wed Jul 21 2004 kukuk@suse.de
- Add pam_resmgr.so to session management of pam.d/login
* Wed Jun 30 2004 kukuk@suse.de
- Add new /etc/default/passwd entries
* Thu Jun 17 2004 bg@suse.de
- Disable selinux for hppa
* Wed May 12 2004 kukuk@suse.de
- Update LAuS patch (signed/unsigned UID/GID)
* Mon May 10 2004 kukuk@suse.de
- Add next LAuS patch
- Fix writing of SKEL and EXPIRE entry in /etc/default/useradd
* Fri Apr 30 2004 kukuk@suse.de
- Update LAuS patch [Bug #39619]
* Thu Apr 29 2004 kukuk@suse.de
- Fix lot of format errors for LAuS [Bug #39619]
- Fix typo in groupmod
* Wed Apr 21 2004 kukuk@suse.de
- Add -A and -R options to groupmod
- Adjust LAuS patch
* Wed Apr 14 2004 kukuk@suse.de
- Fix SLP URL parsing in rpasswd client
* Sat Apr  3 2004 kukuk@suse.de
- Add sg again
* Fri Apr  2 2004 kukuk@suse.de
- Update LAuS Patch (hopefully this one works)
* Thu Apr  1 2004 kukuk@suse.de
- Fix applying of LAuS Patch on SLES9, don't apply on 9.1
- Update to pwdutils 2.6.2: Fix refreshing of SLP registration
* Thu Apr  1 2004 thomas@suse.de
- added LAuS patches from IBM
* Wed Mar 24 2004 kukuk@suse.de
- Update pwdutils to 2.6.1: Ignore setgroups errors in newgrp
* Wed Mar 17 2004 kukuk@suse.de
- Update pwdutils to 2.6 (Add missing grpck/pwck functionality,
  add test cases for pwck and grpck).
* Mon Mar 15 2004 kukuk@suse.de
- Update to pam_login 3.18 [Bug #35238]
- Update pwdutils to 2.5.98 (fix for groupmod flushing wrong cache)
* Fri Mar  5 2004 kukuk@suse.de
- Don't dlclose not loaded NSS modules [Bug #35331]
* Tue Feb 24 2004 kukuk@suse.de
- Update to 2.5.97 (lot of small fixes)
* Tue Feb 17 2004 kukuk@suse.de
- Fix typo in /etc/login.defs
* Mon Feb 16 2004 kukuk@suse.de
- Start converting between UTF-8 and currently used locale
- Read regex expression for allowed usernames from /etc/login.defs
- Lot of bug fixes
* Fri Feb  6 2004 kukuk@suse.de
- Add /etc/default/passwd support
* Thu Feb  5 2004 kukuk@suse.de
- Add manual pages for newgrp and pam_rpasswd
* Sun Feb  1 2004 kukuk@suse.de
- Add POSIX conform newgrp
* Wed Jan 28 2004 kukuk@suse.de
- Update to pwdutils 2.5.91 (fixes compile problems on some archs)
- Enable SLP support in rpasswdd
* Wed Jan 28 2004 kukuk@suse.de
- Update to pwdutils 2.5.90 (Add pam_rpasswd,pwck,grpck)
- Remove shadow sources (not needed any longer)
* Sat Jan 17 2004 ro@suse.de
- added pam-devel to neededforbuild
* Wed Jan 14 2004 kukuk@suse.de
- Rename package to pwdutils
* Sat Jan 10 2004 kukuk@suse.de
- Update to pwdutils 2.5.1 (pwconv/pwunconv/grpunconv added)
- Only install grpck/pwck from shadow suite
* Wed Jan  7 2004 kukuk@suse.de
- Don't install getspnam.3 (is part of man-pages)
* Wed Dec 10 2003 kukuk@suse.de
- Update to pwdutils 2.4 [Bug #33508]
* Fri Dec  5 2003 kukuk@suse.de
- Update to pwdutils 2.3.99 (usermod and LDAP support fixes)
* Tue Dec  2 2003 kukuk@suse.de
- Update to pwdutils 2.3.97 (gpasswd, groupmod, usermod)
* Wed Oct 29 2003 kukuk@suse.de
- Obsolete cpu (replaced by pwdutils tools)
- Fix group of gpasswd
* Thu Oct 16 2003 kukuk@suse.de
- Update pam_login to 3.16
- Update pwdutils to 2.3.96 (SELinux support, preserve ACLs)
* Mon Oct 13 2003 schwab@suse.de
- Fix alignment warnings.
* Sun Oct 12 2003 kukuk@suse.de
- Update pwdutils (groupadd -g fix)
- Remove sg/newgrp
* Wed Oct  8 2003 kukuk@suse.de
- Update pwdutils (groupadd/groupdel added)
- Update pam_login (SELinux support added)
* Sun Sep 21 2003 kukuk@suse.de
- Set UID_MIN (login.defs) back to 500 [#31515]
* Fri Sep 19 2003 kukuk@suse.de
- Add require to pam-modules to solve update problems
* Thu Sep  4 2003 ro@suse.de
- workaround case where $1 is unset in preinstall script
  (non-rpm usage)
* Thu Sep  4 2003 kukuk@suse.de
- userdel: flush nscd cache after account is deleted
- chsh/chfn: don't ask root for password on local accounts
* Mon Sep  1 2003 kukuk@suse.de
- Don't copy installed /etc/openldap/ldap.conf on new installation
* Mon Aug 11 2003 kukuk@suse.de
- Update to pwdutils snapshot (Add manual pages)
- shadow: Ignore new login.defs variables from pwdutils
* Fri Jul 25 2003 kukuk@suse.de
- Update to pwdutils snapshot (useradd/usrdel can now create/delete
  LDAP accounts)
* Thu Jul 17 2003 kukuk@suse.de
- Fix roff link in getspnam.3 [Bug #27886]
- Update to pwdutils 2.3.91
* Tue Jul 15 2003 kukuk@suse.de
- Update to pam_login 3.12
- Add /etc/ldap.conf
- Change path to ldap.conf from /etc/openldap to /etc
- Update to new pwdutils snapshot
- Add new default/useradd source
* Mon Jul 14 2003 kukuk@suse.de
- Update to pwdutils 2.3.90
- Add /usr/sbin/useradd.local
- Add GROUPS entry to /etc/default/useradd
* Wed Jul  2 2003 kukuk@suse.de
- Update to pwdutils 2.3
* Thu Jun 19 2003 ro@suse.de
- fix build with current gettext (0.12)
* Tue May 27 2003 ro@suse.de
- added cracklib-devel to neededforbuild
* Tue May 13 2003 kukuk@suse.de
- Fix filelist: Add pam_login translations
* Mon May 12 2003 kukuk@suse.de
- Update to pam_login 3.11: Inline fixes for gcc 3.3, add sleep
  before exit in error case.
* Sun Mar  9 2003 kukuk@suse.de
- Fix path to ldap.conf
* Sat Mar  8 2003 kukuk@suse.de
- Adjust 64bit patch
* Sat Mar  8 2003 kukuk@suse.de
- Allow A-Z and . as characters for login names. [Bug #24891]
* Thu Feb 20 2003 kukuk@suse.de
- rpasswdd should use an own copy of PAM configuration file.
* Thu Feb 13 2003 kukuk@suse.de
- Update to pwdutils 2.2 (chage can now change LDAP entries)
* Mon Feb  3 2003 kukuk@suse.de
- Update to pwdutils 2.1 (fixes documentation)
* Mon Jan 27 2003 kukuk@suse.de
- update to pwdutils 2.0
* Mon Jan 20 2003 ro@suse.de
- make pdwutils build again (pwdutils-1.99-libc.dif)
* Mon Jan 13 2003 kukuk@suse.de
- Fix seg.fault introduced through sanity check patch
* Sat Jan 11 2003 kukuk@suse.de
- Fix wrong login.defs comment.
- Enhance the chage manual page (-d option).
* Fri Jan 10 2003 kukuk@suse.de
- Add comment, that /var/log/btmp must exist to enable logging.
* Thu Dec 12 2002 kukuk@suse.de
- Update to pam_login 3.10 (compiles with gcc 3.10, rewrite of the
  controlling tty and Ctrl-\ handling).
- Update to shadow 4.0.3 (mainly man page updates).
- Fix more time() calls for s390x and x86_64.
* Mon Nov 18 2002 ro@suse.de
- add AM_GNU_GETTEXT_VERSION to configure.in
* Tue Nov  5 2002 kukuk@suse.de
- Fix utmp/wtmp handling of pam_login on x86-64, ppc64 and s390x
* Mon Oct 28 2002 sf@suse.de
- fix for segfault on hammer, ppc64 and s390x
  (shadow-4.0.2-64bit.diff) (bug #21345)
* Tue Oct  1 2002 kukuk@suse.de
- Fix copyright message of chage [Bug #20402]
* Mon Aug 26 2002 kukuk@suse.de
- Add sanity checks for rpasswdd [Bug #18322]
* Sun Aug 25 2002 kukuk@suse.de
- Add workaround for new OpenLDAP2 version
* Tue Aug 13 2002 kukuk@suse.de
- Fix IPv4/IPv6 handling
- Include own parser for shadow and passwd entries
* Sun Jul 21 2002 kukuk@suse.de
- Add bugfix for chage (-d and -E options) [Bug #17038]
* Mon Jul 15 2002 kukuk@suse.de
- Update to pwdutils 1.99 (many bug fixes, new chage implementation)
- Fix one more bug in groupdel
* Thu Jul 11 2002 kukuk@suse.de
- Update to pam_login 3.7 (SIGHUP init fix, may solve [Bug #16602])
- Run libtoolize/aclocal/autreconf/automake
- Fix groupdel (option handling, check if group exists)
* Wed May 22 2002 kukuk@suse.de
- Correct last change ...
* Wed May 22 2002 kukuk@suse.de
- Disable USERGROUPS_DEL per default, we don't use user groups.
* Wed May 15 2002 kukuk@suse.de
- Fix typo in login.defs manual page
* Tue May 14 2002 kukuk@suse.de
- fix description for PASS_MAX_LEN
* Fri May 10 2002 kukuk@suse.de
- Update to pwdutils-1.98 (Lot of major bug and security fixes)
* Thu Apr 25 2002 kukuk@suse.de
- Update to pwdutils-1.94 (Fix possible file corruption problems).
- Remove Libraries, which will not end in filelist
* Wed Apr 24 2002 kukuk@suse.de
- Update to pwdutils-1.93 (Fix typo in init script, implement
  sigchild handler)
* Wed Apr 24 2002 kukuk@suse.de
- Update to pwdutils-1.92 (Add remote password update daemon)
* Tue Apr 16 2002 kukuk@suse.de
- Implement -P option for groupadd, groupmod, groupdel, useradd,
  usermod and userdel (specify an alternate path to passwd/group).
- Link against libxcrypt.
* Mon Feb 18 2002 kukuk@suse.de
- Update to shadow 4.0.2 (mainly fixed translations)
- Add correct manual pages for chfn and chsh
* Fri Jan 25 2002 kukuk@suse.de
- Update pam_login to 3.6 (fix Ctrl-\ bug killing login)
- Update pwdutils to 1.91 (major bug fixes for chfn/chsh)
* Tue Jan 22 2002 kukuk@suse.de
- Use chfn,chsh and passwd from pwdutils package (with NIS and LDAP
  support)
* Tue Jan  8 2002 kukuk@suse.de
- Fix .so reference in vigr.8/sg.1 manual pages
* Mon Jan  7 2002 kukuk@suse.de
- correct vigr/vipw links
* Mon Jan  7 2002 kukuk@suse.de
- Update to pam_login 3.5 (-r option added)
- Update to shadow 4.0.1
- add more 32bit uid/gid fixes
* Sat Jan  5 2002 kukuk@suse.de
- Enable PAM for all applications
* Fri Jan  4 2002 kukuk@suse.de
- Correct fix for install-hook
* Fri Jan  4 2002 kukuk@suse.de
- Update to CVS snapshot from 22.12.2001
* Fri Jan  4 2002 kukuk@suse.de
- Add -r option to useradd to be LSB conform
- Add -r option to groupadd to be compatible with useradd
- Increase GID_MIN to 500.
* Thu Nov 15 2001 kukuk@suse.de
- Fix some compiler warnigs (partial [Bug #12274])
* Thu Nov  8 2001 kukuk@suse.de
- Fix .so reference in manual pages
* Thu Nov  8 2001 kukuk@suse.de
- Disable PAM for standard sysadmin utilities
- Make newusers 32bit UID clean
* Tue Oct 30 2001 kukuk@suse.de
- Update to shadow 4.0.0, many new features, all tools are now
  PAM aware
- Add grpconv/grpunconv to filelist [Bug #5404]
- Update pam_login to 3.4 (uses reentrant functions)
* Thu Oct 11 2001 kukuk@suse.de
- Fix problem with login that pam modules could overwrite user data
* Thu Oct  4 2001 schwab@suse.de
- Fix for automake 1.5.
* Tue Sep 11 2001 kukuk@suse.de
- Fix bug where group entries are truncated if the line is longer
  then 4096 bytes.
* Mon Sep  3 2001 kukuk@suse.de
- Use LFS to support 32bit UIDs
- Fix a lot of bugs vs. 32bit support
* Tue Aug 14 2001 kukuk@suse.de
- Remove absolute paths from login config file for PAM
* Mon Jul 30 2001 kukuk@suse.de
- Move default/useradd from aaa_base into this package
- Use real defaults for default/useradd [Bug #9366]
- Mark as config/noreplace
* Mon Jun  4 2001 kukuk@suse.de
- Fix to compile with new tools
* Fri May 11 2001 schwab@suse.de
- Fix missing declarations.
* Sun Apr 29 2001 kukuk@suse.de
- Add UMASK back to /etc/login.defs [Bug #7383]
* Sat Apr 21 2001 kukuk@suse.de
- Fix flushing of nscd cache to work on all plattforms
* Thu Apr 12 2001 kukuk@suse.de
- Call gettextize
* Thu Apr 12 2001 kukuk@suse.de
- Add vigr [Bug #6926]
- Disable at first workarounds for ash [Bug #6928]
- Add uggly workaround for new gettext
* Wed Mar 28 2001 kukuk@suse.de
- Remove parts of pam_login 3.2 fixes (contains race conditions)
* Sat Mar 24 2001 kukuk@suse.de
- pam_login: Update to version 3.2
* Sat Feb  3 2001 violiet@suse.de
- added Japanese and Korean message file.
* Wed Dec  6 2000 kukuk@suse.de
- set min. UID for new user to 500.
- Remove 16bit ID patches to allow 32bit UIDs and GIDs
* Thu Sep 14 2000 kukuk@suse.de
- pam_login: Add new login.defs variable
* Wed Sep 13 2000 kukuk@suse.de
- Fix version string in spec file
- Remove more obsolete man pages
* Wed Sep 13 2000 ro@suse.de
- removed su-manpage: is in sh_utils
* Tue Sep 12 2000 kukuk@suse.de
- Update to shadow-20000902
- Use buildroot
* Sat Jul 15 2000 kukuk@suse.de
- Disable pam_homecheck from pam login config file
* Fri May  5 2000 kukuk@suse.de
- Add pam_homecheck to login pam config file
* Fri Apr 14 2000 kukuk@suse.de
- Update pam_login to 3.1.1
* Sun Apr  2 2000 bk@suse.de
- replaced config.{guess,sub} patches with config update macro (s390)
* Thu Feb  3 2000 schwab@suse.de
- Update config.{guess,sub} to latest version.
* Fri Jan 21 2000 kukuk@suse.de
- Add missing login.defs entries to pam_login
* Mon Jan 17 2000 kukuk@suse.de
- Fix typo on pam config files
* Mon Jan 17 2000 kukuk@suse.de
- pam_login: Update to 3.1
- shadow: Update pam config files, login.defs and manual page
- Move /usr/man to /usr/share/man
* Tue Oct 26 1999 kukuk@suse.de
- login.defs: Remove unsupported PASS_MIN_LEN/PASS_MAX_LEN
* Sat Oct 23 1999 kukuk@suse.de
- shadow: Add expiry.1 manual page
- shadow: Add fixes from current development (BUG#663)
- shadow/chage: Don't need to be suid root any longer
* Mon Oct 11 1999 kukuk@suse.de
- Upgrade to pam_login 3.0
- Clear nscd cache after changes on passwd/group
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Sat Sep 11 1999 kukuk@suse.de
- Implement LOG_UNKFAIL_ENAB option
- login: Show tty name if we don't have a hostname
* Mon Sep  6 1999 kukuk@suse.de
- login: set USER env. variable
* Fri Sep  3 1999 kukuk@suse.de
- Update to shadow 19990827
- Add LOGIN_RETRIES and LOGIN_TIMEOUT to login
- Specfile cleanup
* Mon Jul 12 1999 kukuk@suse.de
- Update to shadow 19990709
* Tue Jul  6 1999 kukuk@suse.de
- login.pamd: put pam_securtty after pam_unix
- shadow: Add patches from Thomas Biege
* Wed Jun 30 1999 kukuk@suse.de
- Include PAM patch for chfn
* Sun Jun 27 1999 kukuk@suse.de
- Fix filelist
- Fix nullok parameters in *.pamd
* Fri Jun 25 1999 kukuk@suse.de
- Finish pam_login 2.9s
* Mon Jun 21 1999 kukuk@suse.de
- Patch shadow chfn/chsh to use PAM
* Tue Jun 15 1999 kukuk@suse.de
- login: Implement FAIL_DELAY, fix pam.d/login config file
- Update shadow to 19990607
* Fri Jun  4 1999 kukuk@suse.de
- Add login-2.9s.tar.gz
- Use PAM
* Tue Mar  9 1999 ro@suse.de
- removed "-pipe" : yields problems
* Mon Feb  1 1999 ro@suse.de
- changed check for libcrypt in Makefile.Linux
  to match on alpha as well
* Thu Jan 14 1999 florian@suse.de
- add vipw with man-page to the filelist
* Sat Dec  5 1998 bs@suse.de
- set PASS_MIN_DAYS to 0 in /etc/login.defs (10000 also means 0 but
  confuses the user).
* Mon Nov 23 1998 ro@suse.de
- check if size of login.defs > 0
* Tue Oct  6 1998 ro@suse.de
- re-added login.defs
* Tue Sep 29 1998 ro@suse.de
- re-activated newgrp, chfn, chsh et. al. / removed no-suid
* Wed Sep  9 1998 ro@suse.de
- added /usr/bin/no-suid to file-list
* Mon Aug 31 1998 ro@suse.de
- upgrade to shadow-980724 with jurix-diff
  - mkpasswd is no longer included (was broken anyway)
  - sg is disabled / resides in usr/bin
  - faillog and lastlog reside in usr/bin
  - pw_auth.3 and pwauth.8 are no longer installed
- check for libcrypt when linking login
* Tue Feb 17 1998 ro@suse.de
- added installation of pwconv and pwconv.8 to Makefile.Linux
* Sat Feb 14 1998 bs@suse.de
- took pwconv into file list.
* Thu Aug 21 1997 bs@suse.de
- disabled ULIMIT in /etc/login.defs
* Tue Jun  3 1997 bs@suse.de
- switched to /etc/nologin in etc/login.defs
* Fri May 16 1997 bs@suse.de
- removed /etc/login.defs.new -> /etc/login.defs behavior, since is not
  neded for rpm.
* Thu Jan  2 1997 bs@suse.de
- login: fixed "*" as passwd. ("*" didn't lead to a lookup in shadow)
* Thu Jan  2 1997 florian@suse.de
- completely new version
- disable the CONSOLE line in /etc/login.defs if you want to allow
  root login from any device
- useradd has a range of uids for new users. Please see /etc/login.defs
  and the man-pages for more information.
* Thu Jan  2 1997 florian@suse.de
- completely new version
* Thu Jan  2 1997 bs@suse.de
  moved configuration files to aaa_base.tgz
